
# colorclip 1.0.4

![Colorclip](https://i.ibb.co/4pKgVFf/Screenshot-2023-06-13-18-33-16-81-e4424258c8b8649f6e67d283a50a2cbc.jpg)

Color pack library,python terminal console

### Installation
```
pip install colorclip
```
### Usage
Import all name
```
from colorclip import *
```
Test
```
print(red('sample string'))
print(bold('bold string'))
```
Background color
```
print(bg_black(lime('sample string')))
```
Check available color
```
p_ac()
```
Help
```
help()
```
AND MORE
